@@ -1,8 +1,9 @@
-__author__ = 'fcanas'
+from IzVerifier.logging.reporter import display_paths
 from IzVerifier.izspecs.containers.constants import *
 
+__author__ = 'fcanas'
 
-def test_verify_all_dependencies(verifier):
+def test_verify_all_dependencies(verifier, verbosity=0, fail_on_undefined_vars=False):
     """
     For the given installer conditions, verify the dependencies for every single one of the conditions
     that are in some way referenced in specs or source.
@@ -10,8 +11,8 @@ def test_verify_all_dependencies(verifier):
 
     return_value = 0
 
-    crefs = verifier.find_code_references('conditions')
-    srefs = verifier.find_spec_references('conditions')
+    crefs = set([ref[0] for ref in verifier.find_code_references('conditions')])
+    srefs = set([ref[0] for ref in verifier.find_spec_references('conditions')])
 
     conditions = verifier.get_container('conditions')
     variables = verifier.get_container('variables')
@@ -19,21 +20,19 @@ def test_verify_all_dependencies(verifier):
 
 
     for condition in drefs | srefs | crefs:
-
         result = verify_dependencies(condition, conditions, variables)
         fail = True
         if result:
             last_path = list(result)[-1]
             if 'variable' in last_path[-1]:
-                fail = False # indicates undefined variable, so we return a warning
+                fail = fail_on_undefined_vars
             else:
                 return_value += 1 # indicates an undefined condition, so we fail
-
-        if result: display_paths(result)
+            if fail and verbosity > 0:
+                display_paths(result)
     return return_value
 
 
-
 def test_verify_dependencies(id, conditions, variables):
     """
     Verifies that the given condition id is defined, and that its' dependencies and
@@ -66,6 +65,8 @@ def _verify_dependencies(id, conditions, variables, undefined_paths, current_pat
     tup = (id, 'condition')
     current_path += (tup,)
 
+    ids = conditions.get_keys()
+
     # Exception for izpack conditions:
     if id in conditions.properties[WHITE_LIST]:
         return undefined_paths
@@ -107,27 +108,5 @@ def _verify_dependencies(id, conditions, variables, undefined_paths, current_pat
     return undefined_paths
 
 
-def display_paths(paths):
-    """
-    Human readable output for displaying dependency paths.
-    """
-    def node_printer(node):
-        return str(node[0]) + "(" + node[1] + ")"
 
-    for path in paths:
-        tab = 0
-        for node in path:
-            if type(node[0]) is tuple:
-                id = node[0][0]
-            else:
-                id = node[0]
-
-            if tab:
-                branch = u'\u02ea\u2192 '
-            else:
-                branch = ''
-            tab += 3
-
-            print " " * tab + branch + str(id) + " : (" + str(node[1]) + ")"
-    print
 
