@@ -191,7 +191,7 @@ class Seeker:
         if compound_matcher.match(key):
             return None
         elif literal_matcher.match(key):
-            pass
+            key = key[1:-1] # strip quotes
         # otherwise it's hopefully just a variable, likely runtime, but we can look for it.
         elif variable_matcher.match(key):
             key = self.find_variable_value(key, location, white_list)
@@ -285,7 +285,12 @@ class Seeker:
         values = set()
         for ele in elements:
             if ele.has_attr(attribute):
-                values.add(str(ele[attribute]))
+                atty = ele[attribute]
+                if type(atty) is list:
+                    for a in atty:
+                        values.add(a)
+                else:
+                    values.add(atty)
         return values
 
     @staticmethod
