@@ -1,11 +1,13 @@
 import importlib
-from IzVerifier.izspecs.izproperties import IzProperties
+from IzVerifier.izspecs.containers.izclasses import IzClasses
 
+from IzVerifier.izspecs.izproperties import IzProperties
 from IzVerifier.izspecs.verifiers.dependencies import test_verify_all_dependencies
 from IzVerifier.izspecs.verifiers.seeker import Seeker
 from IzVerifier.izspecs.containers.constants import *
 from IzVerifier.exceptions.IzVerifierException import IzArgumentsException
 from IzVerifier.izspecs.izpaths import IzPaths
+from IzVerifier.logging.reporter import Reporter
 
 
 __author__ = 'fcanas'
@@ -30,15 +32,17 @@ class IzVerifier():
         }
         """
         validate_arguments(args)
+        self.reporter = Reporter()
         self.specifications = ['conditions', 'variables', 'strings']
         self.containers = {}
-        self.installer = args.get('installer')
         self.sources = args.get('sources', [])
+
         if args.has_key('pom'):
             self.properties = IzProperties(args['pom'])
         else:
             self.properties = None
         self.paths = IzPaths(args['specs_path'], args['resources_path'], self.properties)
+        self.fill_classes()
         self.seeker = Seeker(self.paths)
 
     def verify_all(self, verbosity=0):
@@ -56,8 +60,7 @@ class IzVerifier():
         """
         Runs a verification on the given izpack spec: conditions, strings, variables, etc.
         """
-        templates = ' [ {0:.<40}missing in specs{1:.>40} ] '
-        templatec = ' [ {0:.<40}missing in code{1:.>40} ] '
+
         container = self.get_container(specification)
         defined = container.get_keys()
         crefs = self.find_code_references(specification)
@@ -67,12 +70,8 @@ class IzVerifier():
         smissing = undefined(defined, srefs)
 
         if verbosity > 0:
-            print
-            print templatec.format(specification, len(cmissing))
-            report_set(cmissing)
-            print
-            print templates.format(specification, len(smissing))
-            report_set(smissing)
+            self.reporter.report_test('unreferenced {0} in code'.format(specification), cmissing)
+            self.reporter.report_test('unreferenced {0} in specs'.format(specification), smissing)
 
         return cmissing | smissing
 
@@ -126,11 +125,60 @@ class IzVerifier():
         hits = self.seeker.search_specs_for_attributes(args)
         return hits
 
-    def dependency_verification(self):
+    def dependency_verification(self, verbosity=0, fail_on_undefined_vars=False):
         """
         Run a conditions dependency graph search.
         """
-        test_verify_all_dependencies(self)
+        results = test_verify_all_dependencies(self, verbosity, fail_on_undefined_vars=fail_on_undefined_vars)
+        return results
+
+    def find_references(self, rid, specs=None, verbosity=0):
+        """
+        Finds all references to the given id in source code and specs file for any of the given specs.
+        """
+        results = set()
+
+        if not specs:
+            specs = self.specifications
+
+        for spec in specs:
+            results |= self.find_reference(spec, rid, verbosity)
+
+        return results
+
+    def find_reference(self, spec, rid, verbosity=0):
+        """
+        Find all references to the given id in source and specs for the given spec.
+        Returns a set of tuple results.
+        """
+        container = self.get_container(spec)
+
+        props = {
+            'path': self.paths.root,
+            'id': rid,
+            'specs': map(self.paths.get_path, container.properties[REFERENCE_SPEC_FILES]),
+            'filter_fn': container.has_reference,
+            'attributes': container.properties[ATTRIBUTES],
+            'transformer': lambda x: x,
+            'patterns': container.properties[PATTERNS],
+            'source_paths': self.sources,
+            'white_list_patterns': container.properties[WHITE_LIST_PATTERNS]
+        }
+        results = self.seeker.find_id_references(props)
+        if verbosity > 0:
+            self.reporter.report_test('references to {0} in {1}'.format(rid, spec), results)
+        return results
+
+    def fill_classes(self):
+        """
+        Fills a 'classes container' with custom class info from source code paths.
+        """
+        container = IzClasses()
+
+        for path in self.sources:
+            container.parse(path)
+        self.containers['classes'] = container
+
 
 def validate_arguments(args):
     """
@@ -175,14 +223,3 @@ def quote_remover(key):
         key = quote_remover(''.join(key.split('=')[1:]))
     return key
 
-def report_set(entities):
-    """ Human-readable report for a set of unverified entities. """
-    template = ' [ {0:.<40}{1:.>40} ] '
-    template1 = ' [ {0:.<80} ] '
-
-    for item in sorted(entities):
-        if type(item) is tuple:
-            print template.format(item[0], item[1])
-        else:
-            print template1.format(item)
-
