@@ -1,3 +1,5 @@
+from IzVerifier.izspecs.containers.izclasses import IzClasses
+
 __author__ = 'fcanas'
 
 import unittest
@@ -11,7 +13,7 @@ from IzVerifier.izspecs.containers.constants import *
 
 path1 = 'data/sample_installer_iz5/izpack/'
 path2 = 'data/sample_installer_iz5/resources/'
-source_path2 = 'data/sample_code_base'
+source_path2 = 'data/sample_code_base/src/'
 pom = 'data/sample_installer_iz5/pom.xml'
 
 
@@ -30,6 +32,7 @@ class TestVerifier(unittest.TestCase):
             'specs': ['conditions', 'strings', 'variables']
         }
         self.izv = IzVerifier(args)
+        self.izv.reporter.set_terminal_width()  # Sets width to width of terminal
 
     def test_IzPaths(self):
         """
@@ -60,7 +63,7 @@ class TestVerifier(unittest.TestCase):
 
         # Test for number of keys in conditions.xml plus white list
         num = len(izc.get_keys()) - len(izc.properties[WHITE_LIST])
-        self.assertEquals(num, 4, str(num) + "!=4")
+        self.assertEquals(num, 5, str(num) + "!=5")
 
     def test_langpack_paths(self):
         """
@@ -130,6 +133,36 @@ class TestVerifier(unittest.TestCase):
         num = len(hits)
         assert(num != 0)
 
+    def test_findReference(self):
+        """
+        Find some references to items in source code and specs.
+        """
+        hits = self.izv.find_references('some.user.password', verbosity=2)
+        self.assertEquals(len(hits), 2)
+
+        hits = self.izv.find_references('password.empty', verbosity=2)
+        self.assertEquals(len(hits), 1)
+
+        # Ref in code
+        hits = self.izv.find_references('some.string.3', verbosity=2)
+        self.assertEquals(len(hits), 1)
+
+        # var substitution not yet implemented for find references, so this
+        # test will miss the ref in Foo.java
+        hits = self.izv.find_references('some.condition.1', verbosity=2)
+        self.assertEquals(len(hits), 1)
+
+    def test_izclasses(self):
+        """
+        Testing the izclasses container.
+        """
+        classes = IzClasses(source_path2)
+        classes.print_keys()
+        self.assertEquals(len(classes.get_keys()), 1)
+
+        hits = self.izv.verify('classes', verbosity=2)
+        self.assertEquals(len(hits), 2)
+
 
 if __name__ == '__main__':
     unittest.main()
